===============================
Feature Vector Matrix
===============================

.. image:: https://badge.fury.io/py/featurevectormatrix.png
    :target: http://badge.fury.io/py/featurevectormatrix

.. image:: https://travis-ci.org/talentpair/featurevectormatrix.png?branch=master
        :target: https://travis-ci.org/talentpair/featurevectormatrix

.. image:: https://pypip.in/d/featurevectormatrix/badge.png
        :target: https://pypi.python.org/pypi/featurevectormatrix


Python class to encapsulate different representations of large datasets

* Free software: BSD license
* Documentation: https://featurevectormatrix.readthedocs.org.

Features
--------

* Python class to encapsulate different representations of large datasets
* Rows can be inserted as python dictionaries or arrays
* They can be pulled out as dictionaries or arrays